"""Add meeting table

Revision ID: 96a6aafa05d6
Revises: 6205b7a86c7f
Create Date: 2023-08-06 09:29:49.081693

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "96a6aafa05d6"
down_revision = "6205b7a86c7f"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "meeting",
        sa.Column(
            "meeting_id",
            sa.Integer(),
            nullable=False,
            comment="Serial meeting ID partitioned within crn.",
        ),
        sa.Column("crn", sa.String(length=5), nullable=False),
        sa.Column("start_date", sa.Date(), nullable=False, comment="Start date."),
        sa.Column("end_date", sa.Date(), nullable=False, comment="End date."),
        sa.Column(
            "days",
            postgresql.ARRAY(sa.String(3)),
            nullable=True,
            comment="Days of the week offering meets on.",
        ),
        sa.Column("start_time", sa.Time(), nullable=True, comment="Start time."),
        sa.Column("end_time", sa.Time(), nullable=True, comment="End time."),
        sa.Column(
            "campus",
            sa.String(length=30),
            nullable=True,
            comment="Meeting campus.",
        ),
        sa.Column(
            "room",
            sa.String(length=10),
            nullable=True,
            comment="Meeting room.",
        ),
        sa.ForeignKeyConstraint(["crn"], ["offering.crn"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("meeting_id", "crn"),
        comment="Offering meeting times.",
    )
    op.drop_column("offering", "meeting_time")
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("meeting")
    op.add_column(
        "offering",
        sa.Column(
            "meeting_time",
            sa.TEXT(),
            autoincrement=False,
            nullable=False,
            comment="Offering meeting time.",
        ),
    )
    # ### end Alembic commands ###
